@@ -23,10 +23,10 @@ import unittest
 def test_suite():
     names = [
         'test_commands',
+        'test_dates',
         'test_errors',
         'test_filter_processor',
         'test_helpers',
-        'test_head_tracking',
         'test_parser',
         ]
     module_names = ['fastimport.tests.' + name for name in names]
